export declare const AGENTUITY_CLI_MARK = "\u2A3A";
type ToolArgsInput = string | Record<string, unknown> | undefined;
export interface ToolDisplayDescriptor {
    toolName: string;
    toolArgs?: string;
    fullLabel: string;
    branded: boolean;
}
export declare function getAgentuityCliCommandRemainder(command?: string): string | null;
export declare function formatToolDisplay(toolName: string, rawArgs?: ToolArgsInput): ToolDisplayDescriptor;
export {};
//# sourceMappingURL=agentuity-cli.d.ts.map