import type { ExtensionContext } from '@mariozechner/pi-coding-agent';
import type { RpcUiRequest } from './remote-session.ts';
export declare const REMOTE_FIRE_AND_FORGET_UI_METHODS: Set<string>;
export declare function handleRemoteUiRequest(ctx: ExtensionContext, request: RpcUiRequest): Promise<unknown>;
//# sourceMappingURL=remote-ui-handler.d.ts.map