import type { RpcEvent } from './remote-session.ts';
export declare const REMOTE_RUNTIME_OPERATION_MESSAGE = "Remote controller mode only supports the current sandbox session.";
type RemoteRuntimeOperation = '/new' | '/resume' | '/fork' | '/import';
interface RemoteRuntimeGuards {
    newSession?: () => Promise<unknown>;
    switchSession?: () => Promise<unknown>;
    fork?: () => Promise<unknown>;
    importFromJsonl?: () => Promise<unknown>;
}
interface RemoteSessionEventTarget {
    _handleAgentEvent?: (event: RpcEvent) => void;
}
export declare function dispatchRemoteSessionEvent(session: RemoteSessionEventTarget, event: RpcEvent): void;
export declare function installRemoteRuntimeOperationGuards(runtime: RemoteRuntimeGuards, onBlocked: (operation: RemoteRuntimeOperation) => void): void;
export {};
//# sourceMappingURL=remote-runtime.d.ts.map