export declare function buildInboundRpcPromptText(command: Record<string, unknown>): string | null;
export declare function getInboundRpcDeliverAs(commandType: string, isIdle: boolean): 'steer' | 'followUp' | undefined;
//# sourceMappingURL=inbound-rpc.d.ts.map