import type { ExtensionAPI } from '@mariozechner/pi-coding-agent';
export type KnownApi = 'openai-completions' | 'mistral-conversations' | 'openai-responses' | 'azure-openai-responses' | 'openai-codex-responses' | 'anthropic-messages' | 'bedrock-converse-stream' | 'google-generative-ai' | 'google-gemini-cli' | 'google-vertex';
export declare function setupAIGateway(pi: ExtensionAPI): Promise<void>;
//# sourceMappingURL=aigateway.d.ts.map